==> apache-apisix-dashboard-2.9.0-src.tgz: web/src/pages/Consumer/locales/en-US.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export default {
  'page.consumer.form.itemRuleMessage.username':
    'Maximum length is 100, only letters, numbers and _ are supported, and can only begin with letters',
  'page.consumer.form.itemExtraMessage.username': 'Name should be unique',
  'page.consumer.notification.warning.enableAuthenticationPlugin':
    'Please enable at least one of the following authentication plugin:',
  'page.consumer.username': 'Name',
  'page.consumer.username.required': "Please enter the Consumer's name",
  'page.consumer.updateTime': 'Update Time',
  'page.consumer.list': 'Consumer List',
  'page.consumer.description':
    'Consumers are the consumers of Routes, e.g developers, end users, API calls, etc. When creating a consumer, you need to bind at least one Authentication plugin.',
  'page.consumer.create': 'Create Consumer',
  'page.consumer.configure': 'Configure Consumer',
};

==> apache-apisix-dashboard-2.11.0-src.tgz: web/src/pages/Consumer/locales/en-US.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export default {
  'page.consumer.form.itemRuleMessage.username':
    'Maximum length is 100, only letters, numbers and _ are supported.',
  'page.consumer.form.itemExtraMessage.username': 'Name should be unique',
  'page.consumer.notification.warning.enableAuthenticationPlugin':
    'Please enable at least one of the following authentication plugin:',
  'page.consumer.username': 'Name',
  'page.consumer.username.required': "Please enter the Consumer's name",
  'page.consumer.updateTime': 'Update Time',
  'page.consumer.list': 'Consumer List',
  'page.consumer.description':
    'Consumers are the consumers of Routes, e.g developers, end users, API calls, etc. When creating a consumer, you need to bind at least one Authentication plugin.',
  'page.consumer.create': 'Create Consumer',
  'page.consumer.configure': 'Configure Consumer',
};
